
'''
	{
		"label": "form proposal keys",
		"fields": {
			"seed": ""
		}
	}
'''

import reelity.instrument.climate as instrument_climate

def perform (fields):
	print ("make card")

	seed = fields ["seed"]


	return;





'''
	
'''

'''
	create_instrument
	
	fields {
		"CWD": CWD,
		"name": name,
		"thermos port": thermos_port,
		"mongo port": mongo_port
	}
'''





import os
from os.path import dirname, join, normpath
import pathlib
import sys
from multiprocessing import Process

from .start_mongo import perform as perform_start_mongo

import reelity.instrument.climate as instrument_climate
import reelity.instrument.thermos.start_dev as flask_dev

import time

def perform (move):
	print ("start thermos");

	assert ("CWD" in move)
	assert ("name" in move)
	assert ("thermos port" in move)
	assert ("mongo port" in move)
	
	name = move ["name"]
	CWD = move ["CWD"]
	thermos_port = move ["thermos port"]
	mongo_port = move ["mongo port"]

	instrument_path = str (normpath (join (CWD, name)))
	instrument_climate.build (instrument_path = instrument_path)

	mongo_DB_directory = str (normpath (join (CWD, name, "mongo_DB_directory")))
	if (not os.path.exists (mongo_DB_directory)):			
		os.mkdir (mongo_DB_directory) 
		
	if (not os.path.isdir (mongo_DB_directory)):
		print ("There is already something at:", mongo_DB_directory)
		return;
	
	perform_start_mongo ({
		"CWD": CWD,
		"name": name,
		
		"mongo port": mongo_port,
		"mongo directory": mongo_DB_directory
	});
	
	time.sleep (2)

	flask_server = Process (
		target = flask_dev.start,
		args = (),
		kwargs = {
			"port": thermos_port
		}
	)
	flask_server.start ()
	
	

	while True:
		time.sleep (1000)








#from reelity._clique.group import clique as clique_group

#import reelity.instrument.awareness_sockets.clique_group as clique_group
#from reelity.instrument.clique_tracks import clique as instrument_clique_tracks
#from reelity.instrument.clique_socket import clique as instrument_clique_socket
import reelity.instrument.clique as instrument_clique
#import reelity.instrument.clique as instrument_clique

import click

def intro ():
	@click.group ()
	def group ():
		pass

	@click.command ("tutorial")
	def sphene_command ():	
		import pathlib
		from os.path import dirname, join, normpath
		this_directory = str (pathlib.Path (__file__).parent.resolve ())
		module_directory = str (normpath (join (this_directory, "..")));

		import carbonado
		carbonado.start ({			
			#
			#	This is the node from which the traversal occur.
			#
			"directory": module_directory,
			
			#
			#	This path is removed from the absolute path of share files found.
			#
			"relative path": module_directory
		})
		
		import time
		while True:
			time.sleep (1000)

	group.add_command (sphene_command)
	group.add_command (instrument_clique.start ())
	
	return group;




#





'''
	import reelity.stage.moves as stage_moves

	effect = stage_moves.perform (
		move = {
			"name": "",
			"fields": {
				
			}
		}
	)
'''

'''
	
'''

'''
	obstacles: {
		"obstacle": {
			"string": ""
		}
	}
'''
import os
from os.path import dirname, join, normpath

import reelity.stage.moves.names.make as make
import reelity.stage.moves.names.propose_join as propose_join
moves = {
	"make": make.perform,
	
	#
	#	proposals
	#
	"propose join": propose_join.perform
}

def records (record):
	print (record)

def perform (
	move = "",
	records = records
):
	if ("name" not in move):
		records (f'The "name" of the move was not given.')
		return;
	
	name = move ["name"];
	if (name in moves):
		return moves [ move ["name"] ] ()


	return {
		"obstacle": {
			"string": f'A move named "{ name }" was not found.'
		}
	}





'''

'''


import json
from os.path import dirname, join, normpath
import os
import traceback


import rich
from flask import Flask, request
import flask_cors

import reelity.instrument.thermos.routes.home.get as get_home_route
import reelity.instrument.thermos.routes.card_generator as card_generator
import reelity.instrument.thermos.routes.vue as vue_route
import reelity.instrument.thermos.routes.moves as moves_route

import reelity.instrument.thermos.utilities.generate_path_inventory as generate_path_inventory
import reelity.instrument.climate as instrument_climate
	

def build (
	records = 1
):
	climate = instrument_climate.retrieve ()

	print ("starting instrument flask service")
	rich.print_json (data = {
		"variables": {
			"frontend dist": climate ["paths"] ["frontend dist"]
		}
	})

	app = Flask (__name__)
	flask_cors.CORS (app)
	
	vue_dist_inventory = generate_path_inventory.beautifully (
		climate ["paths"] ["frontend dist"]
	)
	for entry in vue_dist_inventory:
		print (vue_dist_inventory [entry] ["path"])
	
	vue_route.route (app, vue_dist_inventory)
	card_generator.route (app)
	moves_route.route (app)

	@app.route ("/", methods = [ 'GET' ])
	def route_GET ():
		return get_home_route.present ()	

	@app.route ("/example", methods = [ 'GET' ])
	def route_GET_example ():
		return get_home_route.present ()

	
	
	return app;




'''
	import reelity.stage.moves as stage_moves
	effect = stage_moves.perform (
		move = {
			"name": "",
			"fields": {
				
			}
		}
	)
'''

'''
	returns {
		"victory": "yes"
	}
'''

'''
	returns {
		"victory": "no",
		"alarm": {
			"string": ""
		}
	}
'''

import os
from os.path import dirname, join, normpath

import reelity.instrument.moves.names.make as make
import reelity.instrument.moves.names.start_thermos as start_thermos
import reelity.instrument.moves.names.is_on as is_on

#
#	cards
#
import reelity.instrument.moves.names.cards.make as make_card
import reelity.instrument.moves.names.cards.enumerate as enumerate_cards



moves = {
	"make": make.play,
	"start thermos": start_thermos.perform,
	
	#
	#	is on
	#
	"is on": is_on.perform,
	
	#
	#	cards
	#
	"make card": make_card.perform,
	"enumerate cards": enumerate_cards.perform
}

def records (record):
	print (record)

def perform (
	move = "",
	records = records
):
	if ("name" not in move):
		records (f'The "name" of the move was not given.')
		return;
	
	name = move ["name"];
	if (name in moves):
		return moves [ name ] (move ["fields"])

	return {
		"victory": "no",
		"alarm": {
			"string": f'A move named "{ name }" was not found.',
			"details": moves
		}
	}







import os
	
import rich
		
import reelity.stage.moves as stage_moves

def start ():
	import click
	@click.group ("stage")
	def group ():
		pass

	'''
		stage make --thermos-port 56700 --mongo-port 56701
	'''
	import click
	@group.command ("make")
	@click.option ('--thermos-port', '-tp', default = '55500')
	@click.option ('--mongo-port', '-mp', default = '55501')
	@click.option ('--name', default = 'stage')
	def search (thermos_port, mongo_port, name):	
		CWD = os.getcwd ();
	
		effect = stage_moves.perform (
			move = {
				"name": "make",
				"fields": {
					"CWD": CWD,
					"name": name,
					"thermos port": "",
					"mongo port": ""
				}
			}
		)
		
		rich.print_json (data = effect)
	
		return;

	return group




#







'''
	import reelity.instrument.thermos.start_dev as flask_dev
'''

import reelity.instrument.thermos as instrument_flask

def start (port):
	print ('starting')
	
	app = instrument_flask.build ()
	app.run (port = port)

	return;
	
#if __name__ == "__main__":
#	start ()



'''
	import reelity.instrument.moon.cards.make_ECC_448_2 as make_ECC_448_2
	moon_connection = make_ECC_448_2.start (
		name = "",
		seed = ""
	)
'''

import pymongo

import reelity.instrument.moon.connect as moon_connect
import reelity.modules.EEC_448_2.keys as EEC_448_2_key_creator	

def start (
	name = "",
	seed = ""
):
	moon_connection = moon_connect.start ()
	cards = moon_connection ["pocket"] ["cards"]
	
	keys = EEC_448_2_key_creator.create (
		seed = seed
	)
	
	cards.insert_one ({
		"name": name,
		"format": "ECC_448_2",
		"public": {
			"hexadecimal string": keys ["public"] ["hexadecimal string"]
		},
		"private": {
			"hexadecimal string": keys ["private"] ["hexadecimal string"]
		},
		"seed": {
			"hexadecimal string": seed
		}
	})

	return;